@@ -8,7 +8,7 @@ def main() -> None:
     m.launch()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     try:
         main()
     except KeyboardInterrupt:
